==> react-molecule-autosuggest-2.18.0.tgz: package/lib/hoc/withClearUI.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component } from 'react';
var BASE_CLASS = "sui-MoleculeAutosuggest-input";
var CLASS_CONTAINER = BASE_CLASS + "-container";
var CLASS_ICON_CLEAR = BASE_CLASS + "-icon";
export default (function (BaseComponent) {
  var _class, _temp;

  var displayName = BaseComponent.displayName;
  return _temp = _class = /*#__PURE__*/function (_Component) {
    _inheritsLoose(WithClearUI, _Component);

    function WithClearUI() {
      return _Component.apply(this, arguments) || this;
    }

    var _proto = WithClearUI.prototype;

    _proto.render = function render() {
      /* eslint-disable react/prop-types */
      var _this$props = this.props,
          onClickClear = _this$props.onClickClear,
          isVisibleClear = _this$props.isVisibleClear,
          iconClear = _this$props.iconClear,
          props = _objectWithoutPropertiesLoose(_this$props, ["onClickClear", "isVisibleClear", "iconClear"]);

      return /*#__PURE__*/React.createElement("div", {
        className: CLASS_CONTAINER
      }, /*#__PURE__*/React.createElement(BaseComponent, props), !!isVisibleClear && iconClear && /*#__PURE__*/React.createElement("span", {
        className: CLASS_ICON_CLEAR,
        onClick: onClickClear
      }, iconClear));
    };

    return WithClearUI;
  }(Component), _class.displayName = "WithClearUI(" + displayName + ")", _temp;
});

==> react-molecule-autosuggest-2.21.0.tgz: package/lib/hoc/withClearUI.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import React, { Component } from 'react';
var BASE_CLASS = "sui-MoleculeAutosuggest-input";
var CLASS_CONTAINER = BASE_CLASS + "-container";
var CLASS_ICON_CLEAR = BASE_CLASS + "-icon";
export default (function (BaseComponent) {
  var _class, _temp;

  var displayName = BaseComponent.displayName;
  return _temp = _class = /*#__PURE__*/function (_Component) {
    _inheritsLoose(WithClearUI, _Component);

    function WithClearUI() {
      return _Component.apply(this, arguments) || this;
    }

    var _proto = WithClearUI.prototype;

    _proto.render = function render() {
      /* eslint-disable react/prop-types */
      var _this$props = this.props,
          onClickClear = _this$props.onClickClear,
          isVisibleClear = _this$props.isVisibleClear,
          iconClear = _this$props.iconClear,
          props = _objectWithoutPropertiesLoose(_this$props, ["onClickClear", "isVisibleClear", "iconClear"]);

      return /*#__PURE__*/_jsxs("div", {
        className: CLASS_CONTAINER,
        children: [/*#__PURE__*/_jsx(BaseComponent, _extends({}, props)), !!isVisibleClear && iconClear && /*#__PURE__*/_jsx("span", {
          className: CLASS_ICON_CLEAR,
          onClick: onClickClear,
          children: iconClear
        })]
      });
    };

    return WithClearUI;
  }(Component), _class.displayName = "WithClearUI(" + displayName + ")", _temp;
});
